@@ -24,11 +24,11 @@ class ApproverDaemon : public QObject, public Tp::AbstractClientApprover
 {
     Q_OBJECT
 public:
-    ApproverDaemon(QObject *parent = 0);
+    ApproverDaemon(QObject *parent = nullptr);
 
 protected:
-    virtual void addDispatchOperation(const Tp::MethodInvocationContextPtr<> & context,
-                                      const Tp::ChannelDispatchOperationPtr & dispatchOperation);
+    void addDispatchOperation(const Tp::MethodInvocationContextPtr<> & context,
+                              const Tp::ChannelDispatchOperationPtr & dispatchOperation) override;
 };
 
 #endif // APPROVERDAEMON_H
